@@ -16,7 +16,7 @@ import urllib.request
 from datetime import datetime
 from pathlib import Path
 
-from appdirs import AppDirs
+from platformdirs import PlatformDirs
 import PySide6
 from PySide6.QtCore import QModelIndex, QPoint, QItemSelectionModel, QTimer, Signal, Slot, QItemSelection, QObject, \
     QSize
@@ -97,7 +97,7 @@ class MAPHIS(QMainWindow):
 
         self._setup_version_checking()
 
-        self._app_dirs = AppDirs("MAPHIS", "CBIA")
+        self._app_dirs = PlatformDirs("MAPHIS", "CBIA")
         self.config: typing.Dict[str, typing.Any] = {}
         self.load_config()
 
@@ -1233,8 +1233,12 @@ class MAPHIS(QMainWindow):
         self._hovered_label = label
         #info = f'{self.state.colormap.label_names[label]} - code {self.state.label_hierarchy.code(label)}'
         lab_hier = self.state.label_hierarchy
-        info = f'{lab_hier.nodes[label].name} - code {lab_hier.nodes[label].code}'
-        color = self.state.colormap[label]
+        if label not in lab_hier.nodes:
+            info = 'label not present in current label hierarchy'
+            color = (0, 0, 0)
+        else:
+            info = f'{lab_hier.nodes[label].name} - code {lab_hier.nodes[label].code}'
+            color = self.state.colormap[label]
         self.label_color_pixmap.fill(QColor.fromRgb(*color, 255 if label > 0 else 0))
         self.label_editor.ui.lblLabelIcon.setPixmap(self.label_color_pixmap)
         self.label_editor.ui.lblLabelInfo.setText(info)
