@@ -5,6 +5,8 @@ from pathlib import Path
 
 from PySide6.QtGui import QIcon
 
+from maphis import MAPHIS_PATH
+
 
 class IconStorage:
     _instance: typing.Optional['IconStorage'] = None
@@ -14,14 +16,14 @@ class IconStorage:
 
     def load_icons(self) -> bool:
         try:
-            with importlib.resources.path('maphis', 'resources') as res_path:
-                for dir_entry in os.scandir(res_path):
-                    if dir_entry.is_dir() or not dir_entry.name.endswith('png'):
-                        continue
-                    icon_path = Path(dir_entry.path)
-                    icon_name = icon_path.stem   # without the extension
-                    icon = QIcon(str(icon_path))
-                    self._icons[icon_name] = icon
+            res_path = MAPHIS_PATH / 'resources'
+            for dir_entry in os.scandir(res_path):
+                if dir_entry.is_dir() or not dir_entry.name.endswith('png'):
+                    continue
+                icon_path = Path(dir_entry.path)
+                icon_name = icon_path.stem   # without the extension
+                icon = QIcon(str(icon_path))
+                self._icons[icon_name] = icon
         except Exception:
             return False
         return True
