@@ -55,6 +55,7 @@ class LabelHierarchy:
         self.name = ''
         self._level_groups: List[Set[int]] = []
         self.mask_label: Optional[Node] = None
+        self.nodes_by_level: typing.List[typing.List[Node]] = []
 
     @classmethod
     def are_valid_masks(cls, masks: List[int], n_bits: int = 32) -> bool:
@@ -220,10 +221,15 @@ class LabelHierarchy:
             label = self.label(label_or_code)
         else:
             label = label_or_code
-        # #mask = self.get_mask(label)
-        # #index = self.masks.index(mask)
-        # return self.get_level(label) - 1  # For top level mask (index 0), -1 is correct, meaning it does not have a parent
-        return self.parents[label]
+        if label in self.parents:
+            return self.parents[label]
+        level = self.get_level(label)
+        if level == 0:
+            return -1
+        parent_mask = self.get_label_mask_up_to(level - 1, label)
+        # mask = self.get_mask(label)
+        # index = self.masks.index(mask)
+        return label & parent_mask
 
     def get_ancestors(self, label: int) -> List[int]:
         """Returns the list of ancestor labels for `label`."""
@@ -276,6 +282,38 @@ class LabelHierarchy:
         self.compute_children()
 
     def compute_children(self):
+        # self.nodes_by_level = [[] for _ in range(len(self.masks))]
+        # for node in self.nodes.values():
+        #     if node.label < 0:
+        #         continue
+        #     level = self.get_level(node.label)
+        #     self.nodes_by_level[level].append(node)
+
+        self._create_root_node()
+
+        for node in sorted(self.nodes.values(), key=lambda _node: _node.label):
+            if node.label < 0:
+                continue
+            level = self.get_level(node.label)
+            if level == 0:
+                self.parents[node.label] = -1
+                node.parent = self.nodes[-1]
+                self.children.setdefault(-1, list()).append(node.label)
+                self.nodes[-1].children.append(node)
+            else:
+                mask = self.get_label_mask_up_to(level - 1, node.label)
+                parent_label = node.label & mask
+                if parent_label not in self.nodes:
+                    # `node` is an orphaned node, should not happen unless the json file was modified manually
+                    # TODO reject the whole label hierarchy or ignore the orphaned labels? For now, I'll adopt the second option
+                    del self.nodes[node.label]
+                    continue
+                self.parents[node.label] = parent_label
+                node.parent = self.nodes[parent_label]
+                self.children.setdefault(parent_label, list()).append(node.label)
+                self.nodes[parent_label].children.append(node)
+
+    def _compute_children(self):
         """Establishes descendant relations between label nodes."""
         self._create_root_node()
         if -1 in self.labels:
@@ -430,7 +468,11 @@ class LabelHierarchy:
 
     def get_available_label(self, parent: int) -> int:
         """Returns the next available child label for `parent`."""
-        last_child = max(self.children[parent], default=0)
+        last_child_node: typing.Optional[Node] = max(self.nodes[parent].children, default=None, key=lambda _node: _node.label)
+        if last_child_node is None:
+            last_child = 0
+        else:
+            last_child = last_child_node.label
         mask = self.get_mask(last_child)
         child_num = last_child & mask
         one = 1 << self.shifts[self.get_level(last_child)]
