@@ -1,5 +1,6 @@
 import dataclasses
 import json
+import logging
 from enum import IntEnum
 from pathlib import Path
 from typing import Optional, Any, List, Dict, Tuple, Union
@@ -17,6 +18,8 @@ from maphis.common.common import Info
 from maphis.common.label_hierarchy import LabelHierarchy
 from maphis.common.units import Value, CompoundUnit, Unit, BaseUnit, SIPrefix
 
+logger = logging.getLogger('LabelImage')
+
 
 class PropertyType(IntEnum):
     String = 0,
@@ -116,22 +119,17 @@ class RegionProperty:
         self._val_names = list(val_names)
 
     @classmethod
-    def from_dict(cls, dict_obj: Dict[str, Any]) -> 'RegionProperty':
+    def from_dict(cls, dict_obj: Dict[str, Any]) -> typing.Optional['RegionProperty']:
         reg_prop = RegionProperty()
         reg_prop.label = dict_obj['label']
         reg_prop.prop_type = PropertyType(dict_obj['prop_type'])
-        if reg_prop.prop_type == PropertyType.NDArray:
-            path_unit = eval(dict_obj['value'])
-            reg_prop.value = (np.load(path_unit[0]), path_unit[1])
-        else:
-            reg_prop.value = eval(dict_obj['value'])
-        # reg_prop.unit = dict_obj['unit']
+        reg_prop.prop_comp_key = dict_obj['prop_comp_key']
+        reg_prop.local_key = dict_obj['local_key']
+
         reg_prop.num_vals = dict_obj['num_vals']
         reg_prop.val_names = dict_obj['val_names']
         reg_prop.col_names = dict_obj['col_names']
         reg_prop.row_names = dict_obj['row_names']
-        reg_prop.prop_comp_key = dict_obj['prop_comp_key']
-        reg_prop.local_key = dict_obj['local_key']
         reg_prop.settings = dict_obj['settings']
         reg_prop._up_to_date = dict_obj.get('up_to_date', True)
         info = Info()
@@ -139,6 +137,19 @@ class RegionProperty:
         info.key = dict_obj['key']
         info.description = dict_obj['description']
         reg_prop.info = info
+
+        if reg_prop.prop_type == PropertyType.NDArray:
+            path_unit = eval(dict_obj['value'])
+            try:
+                measurement_path = Path(dict_obj['label_image_folder']) / path_unit[0]
+                reg_prop.value = (np.load(str(measurement_path)), path_unit[1])
+            except FileNotFoundError:
+                logger.warning(f'Property {reg_prop.info.name} ({reg_prop.prop_comp_key}.{reg_prop.local_key}). The file {path_unit[0]} used by this property was not found. Ignoring.')
+                print(f'Property {reg_prop.info.name} ({reg_prop.prop_comp_key}.{reg_prop.local_key}). The file {path_unit[0]} used by this property was not found. Ignoring.')
+                return None
+        else:
+            reg_prop.value = eval(dict_obj['value'])
+        # reg_prop.unit = dict_obj['unit']
         return reg_prop
 
     def __hash__(self) -> int:
@@ -261,8 +272,9 @@ class LabelImg(QObject):
         """Returns a representation of `RegionProperty.value` in a form suitable for serialization in .json."""
         if reg_prop.prop_type == PropertyType.NDArray:
             path = f'{self._path}_{reg_prop.info.name}_{reg_prop.label}.npy'
+            fname = Path(path).name
             np.save(path, reg_prop.value[0])
-            return repr((path, reg_prop.value[1]))  # return path to the serialized ndarray and the unit that the array is in
+            return repr((fname, reg_prop.value[1]))  # return path to the serialized ndarray and the unit that the array is in
         return repr(reg_prop.value)
 
     def save(self):
@@ -440,7 +452,10 @@ class LabelImg(QObject):
                 props = json.load(f)
             for code in props.keys():
                 for prop_dict in props[code]['measurements']:
+                    prop_dict['label_image_folder'] = str(self.path.parent)
                     reg_prop = RegionProperty.from_dict(prop_dict)
+                    if reg_prop is None:
+                        continue
                     # TODO remove these two if's eventually
                     if (prop_key := reg_prop.prop_comp_key).startswith('arthropod_describer.'):
                         _, suffix = prop_key.split('arthropod_describer.')
