@@ -110,11 +110,14 @@ class LabelTreeModel(QAbstractItemModel):
                               self.index(self.rowCount(QModelIndex())-1, 1, QModelIndex()),
                               [Qt.ForegroundRole])
 
-    def find_index(self, label: int) -> QModelIndex:
+    def find_index(self, label: int) -> typing.Optional[QModelIndex]:
         lab_hier = self.label_hierarchy
         index = self.parent(self.index(0, 0))
+        child = QModelIndex()
 
         while index.isValid():
+            if index == child: # check if we're in an infinite loop (should not happen anymore, but just in case)
+                return QModelIndex()
             for child_idx in range(self.rowCount(index)):
                 # child = index.child(child_idx, 0)
                 child = self.index(child_idx, 0, index)
