@@ -18,7 +18,8 @@ from PySide6.QtWidgets import QMessageBox, QWidget
 from maphis.common.label_hierarchy import LabelHierarchy
 from maphis.common.label_image import LabelImgInfo, RegionProperty
 from maphis.common.local_photo import LocalPhoto
-from maphis.common.photo import Photo, Subscriber, UpdateContext, UpdateEvent, PhotoUpdate, PhotoUpdateType
+from maphis.common.photo import Photo, Subscriber, UpdateContext, UpdateEvent, PhotoUpdate, PhotoUpdateType, \
+    LabelImageUpdate, LabelImageUpdateType
 from maphis.common.storage import IMAGE_REFEX, TIF_REGEX, Storage, StorageUpdate
 from maphis.common.units import Value, CompoundUnit, BaseUnit, SIPrefix, Unit
 from maphis.common.utils import ScaleSetting, ScaleLineInfo
@@ -153,6 +154,8 @@ class LocalStorage(Storage):
         return self._default_label
 
     def get_photo_by_idx(self, idx: int, load_image: bool=True) -> Photo:
+        if idx < 0 or idx >= self.image_count:
+            return None
         photo = self._images[idx]
         for label_name in self._lbl_img_info.keys():
             photo[label_name].label_hierarchy = self._label_hierarchies[label_name]
@@ -298,6 +301,14 @@ class LocalStorage(Storage):
                     if self._tag_used_counter[tag] < 1:
                         storage_update.tags_removed.add(tag)
                 self.photo_tags_update.emit(ev_obj.photo, ev_obj.tags_added, ev_obj.tags_removed)
+        elif event.update_context == UpdateContext.LabelImg:
+            ev_obj: LabelImageUpdate = event.update_obj
+            if ev_obj.update_type == LabelImageUpdateType.PropertiesValid:
+                all_labels_properties_valid = True
+                for photo in self.images:
+                    all_labels_properties_valid = all_labels_properties_valid and photo[ev_obj.label_img.label_info.name].has_valid_measurements()
+                if all_labels_properties_valid:
+                    self.all_labels_properties_up_to_date.emit(ev_obj.label_img.label_info.name)
         self.update_photo.emit(event)
         if storage_update is not None:
             self.storage_update.emit(storage_update)
