@@ -14,6 +14,7 @@ from maphis.common.photo import Photo
 from maphis.common.storage import StorageUpdate
 from maphis.common.units import UnitStore
 from maphis.image_list_model import ImageListSortFilterProxyModel
+from maphis.label_editor.new_label_dialog import NewLabelDialog
 
 
 class LabelConstraint(QObject):
@@ -178,9 +179,11 @@ class State(QObject):
     @primary_label.setter
     def primary_label(self, label: int):
         # self.constraints[self.current_label_name].primary_label = label
-        old_label = self.label_states[self.current_label_name].current_label
-        self.label_states[self.current_label_name].current_label = label
-        self.primary_label_changed.emit(label, old_label)
+        # Check if the chosen label is present in the current label hierarchy
+        if label in self.label_hierarchy.nodes:
+            old_label = self.label_states[self.current_label_name].current_label
+            self.label_states[self.current_label_name].current_label = label
+            self.primary_label_changed.emit(label, old_label)
 
     @property
     def secondary_label(self) -> int:
