@@ -16,8 +16,7 @@ class SIPrefix(IntEnum):
             return ''
         if self == SIPrefix.micro:
             return 'μ'
-        rep = super().__str__()
-        return rep.split('.')[1]
+        return self.name
 
     def __repr__(self) -> str:
         if self == SIPrefix.micro:
@@ -33,8 +32,7 @@ class BaseUnit(IntEnum):
     def __str__(self) -> str:
         if self == BaseUnit.none:
             return ''
-        rep = super().__str__()
-        return rep.split('.')[1]
+        return self.name
 
     def __repr__(self) -> str:
         return f'BaseUnit.{"none" if self == BaseUnit.none else str(self)}'
