@@ -16,6 +16,7 @@ from PySide6.QtGui import QImage, QCursor
 from PySide6.QtWidgets import QFileDialog, QWidget, QMessageBox, QApplication, QPushButton
 import pytesseract
 
+from maphis import MAPHIS_PATH
 from maphis.common.download import DownloadDialog
 from maphis.common.units import Value, Unit, BaseUnit, CompoundUnit, SIPrefix
 
@@ -166,13 +167,13 @@ def get_scale_line_ends(scale_marker: np.ndarray) -> typing.Tuple[int, int, int,
 
 
 def get_reference_length(img: np.ndarray) -> typing.Tuple[str, np.ndarray]:
+    tesseract_bin_path = MAPHIS_PATH / 'bin' / 'Tesseract-OCR' / 'tesseract.exe'
     try:
         if platform.system() == 'Windows':
             if not check_if_tesseract_present():
                 raise pytesseract.TesseractNotFoundError
                 # return '', img
-            with importlib.resources.path('maphis.bin', 'Tesseract-OCR') as p:
-                pytesseract.pytesseract.tesseract_cmd = str(p / 'tesseract.exe')
+            pytesseract.pytesseract.tesseract_cmd = str(tesseract_bin_path)
         rot = img
         for i in range(4):
             rot = cv2.rotate(rot, cv2.ROTATE_90_CLOCKWISE)
@@ -183,9 +184,7 @@ def get_reference_length(img: np.ndarray) -> typing.Tuple[str, np.ndarray]:
                 return text, rot
     except pytesseract.TesseractNotFoundError:
         if platform.system() == 'Windows':
-            with importlib.resources.path('maphis', 'bin') as bin_path:
-                tess_path = bin_path / 'Tesseract-OCR'
-            text = f'Could not locate and download Tesseract OCR. Please download the binary version of Tesseract OCR and install it in the location {tess_path}.'
+            text = f'Could not locate and download Tesseract OCR. Please download the binary version of Tesseract OCR and install it in the location {tesseract_bin_path}.'
         else:
             text = 'Please install Tesseract OCR.'
         QMessageBox.warning(QApplication.activeWindow(), "Tesseract OCR not found", text, QMessageBox.StandardButton.Ok)
@@ -331,21 +330,21 @@ def open_with_default_app(path: Path):
 
 
 def check_if_tesseract_present() -> bool:
-    with importlib.resources.path('maphis', 'bin') as bin_path:
-        tess_path = bin_path / 'Tesseract-OCR'
-        if not tess_path.exists():
-            download_path = bin_path / 'tesseract.zip'
-            download = DownloadDialog("https://gitlab.fi.muni.cz/xmraz3/maphis_pekar_segmentation/-/raw/main/Tesseract-OCR.zip",
-                                      download_path, label='Downloading Tesseract OCR engine.',
-                                      title="First-time initialization")
+    bin_path = MAPHIS_PATH / 'bin'
+    tess_path = bin_path / 'Tesseract-OCR'
+    if not tess_path.exists():
+        download_path = bin_path / 'tesseract.zip'
+        download = DownloadDialog("https://gitlab.fi.muni.cz/xmraz3/maphis_pekar_segmentation/-/raw/main/Tesseract-OCR.zip",
+                                  download_path, label='Downloading Tesseract OCR engine.',
+                                  title="First-time initialization")
 
-            if not download.start():
-                return False
-            shutil.unpack_archive(download_path, download_path.parent)
-            os.remove(download_path)
-            return True
-        else:
-            return True
+        if not download.start():
+            return False
+        shutil.unpack_archive(download_path, download_path.parent)
+        os.remove(download_path)
+        return True
+    else:
+        return True
 
 
 def attempt_to_save_with_retries(save_function: typing.Callable[[Path, typing.Any], typing.Any],
