@@ -4,12 +4,13 @@ from typing import List
 import importlib.resources
 
 import PySide6
-from PySide6.QtCore import Qt, Signal, QRect, QMargins, QRegularExpression
+from PySide6.QtCore import Qt, Signal, QRect, QMargins, QRegularExpression, QModelIndex
 from PySide6.QtGui import QImage, QIcon, QPixmap, QRegularExpressionValidator
 from PySide6.QtWidgets import QWidget, QGraphicsScene, QVBoxLayout, QSizePolicy
 
-from maphis.common.layer import Layer, MouseEventLayer
-from maphis.common.photo import Photo, UpdateContext, UpdateEvent
+from maphis.layers.layer import Layer
+from maphis.layers.mouse_event_layer import MouseEventLayer
+from maphis.common.photo import Photo, UpdateContext, UpdateEvent, LabelImageUpdate, LabelImageUpdateType
 from maphis.common.state import State
 from maphis.common.storage import Storage
 from maphis.common.tool import Tool
@@ -99,7 +100,7 @@ class ImageViewer(QWidget):
         self.storage: typing.Optional[Storage] = None
 
     def _setup_photo_view(self):
-        self.photo_view = CustomGraphicsView(self.state)
+        self.photo_view = CustomGraphicsView()
         self.ui.viewFrame.setLayout(QVBoxLayout())
         self.ui.viewFrame.layout().addWidget(self.photo_view)
         self.photo_view.setScene(self.graphics_scene)
@@ -205,9 +206,11 @@ class ImageViewer(QWidget):
             self.setEnabled(False)
         else:
             self.setEnabled(True)
-            idx = self.state.storage.image_names.index(photo.image_name)
+            # idx = self.state.storage.image_names.index(photo.image_name)
+            idx = self.state.image_list_model.image_paths.index(photo.image_path)
             # TODO in case of a filtered list of photos, the line below does not work with correct count of photos
             self.enable_navigation_buttons(idx)
+        self.state.current_photo = photo
         self.photo_switched.emit(photo)
 
     def set_tool(self, tool: typing.Optional[Tool], reset_current: bool = True):
@@ -244,7 +247,8 @@ class ImageViewer(QWidget):
         self.ui.tbtnLast.setEnabled(enable)
 
     def enable_navigation_buttons(self, idx: int, current_photo_count: int = -1):
-        max_index = self.state.storage.image_count - 1 if current_photo_count < 0 else current_photo_count - 1
+        # max_index = self.state.storage.image_count - 1 if current_photo_count < 0 else current_photo_count - 1
+        max_index = self.state.image_list_model.rowCount(QModelIndex()) - 1 if current_photo_count < 0 else current_photo_count - 1
         self.enable_first_button(idx > 0)
         self.enable_prev_button(idx > 0)
         self.enable_next_button(idx < max_index)
@@ -254,6 +258,9 @@ class ImageViewer(QWidget):
     def _handle_update_photo(self, update: UpdateEvent):
         if update.update_context == UpdateContext.Measurements:
             return
+        if isinstance(update.update_obj, LabelImageUpdate):
+            if update.update_obj.update_type in {LabelImageUpdateType.PropertiesValid, LabelImageUpdateType.PropertiesInvalid}:
+                return
         print(f'reacting to photo update {update.update_context} for {update.photo.image_name}')
         if self.state.current_photo is not None and self.state.current_photo.image_name == update.photo.image_name:
             self.set_photo(self.state.current_photo, False, False)
