@@ -23,6 +23,9 @@ class ComputationWidget(QWidget):
         self.ui.grpRegionSettings.setLayout(QVBoxLayout())
         # self.ui.scrollSettings.setLayout(QVBoxLayout())
 
+        self.ui.btnRegApply.setEnabled(False)
+        self.ui.btnRegApplyAll.setEnabled(False)
+
         self.state = state
         # self.state.update_used_label_list.connect(self._update_region_restrict_model)
 
@@ -63,14 +66,20 @@ class ComputationWidget(QWidget):
         # self.setMaximumWidth(150)
 
     def handle_apply_clicked(self, chkd: bool):
+        if self.current_computation_idx < 0 or self.current_computation_idx >= len(self.computations_model.region_comps):
+            return
         self.apply_computation.emit(self.computations_model.region_comps[self.current_computation_idx],
                                     ProcessType.SELECTED_PHOTOS)
 
     def handle_apply_all_clicked(self, chkd: bool):
+        if self.current_computation_idx < 0 or self.current_computation_idx >= len(self.computations_model.region_comps):
+            return
         self.apply_computation.emit(self.computations_model.region_comps[self.current_computation_idx],
                                            ProcessType.ALL_PHOTOS)
 
     def handle_apply_all_unseg_clicked(self, chkd: bool):
+        if self.current_computation_idx < 0 or self.current_computation_idx >= len(self.computations_model.region_comps):
+            return
         self.apply_computation.emit(self.computations_model.region_comps[self.current_computation_idx],
                                     ProcessType.ALL_UNSEGMENTED)
 
@@ -78,6 +87,8 @@ class ComputationWidget(QWidget):
         self.computations_model.add_computation(computation)
         if self.current_computation_idx < 0:
             self.ui.cmbRegComps.setCurrentIndex(0)
+        self.ui.btnRegApply.setEnabled(True)
+        self.ui.btnRegApplyAll.setEnabled(True)
 
     def _handle_computation_selected(self, idx: int):
         self.current_computation_idx = idx
