@@ -78,7 +78,8 @@ class LabelEditor(QObject):
 
         self._setup_toolbox()
 
-        self._setup_new_label_dialog()
+        # self._setup_new_label_dialog()
+        self._new_label_dialog: typing.Optional[NewLabelDialog] = None
         self._setup_label_tree_widget()
 
         self._tool_param_widgets: typing.List[QWidget] = []
@@ -151,7 +152,11 @@ class LabelEditor(QObject):
         self._label_context_menu.addAction(self._label_context_action_remove_subtree)
 
     def _setup_new_label_dialog(self):
-        self._new_label_dialog = NewLabelDialog(self.state)
+        if self._new_label_dialog is not None:
+            self._new_label_dialog.hide()
+            self._new_label_dialog.deleteLater()
+            self._new_label_dialog = None
+        self._new_label_dialog = NewLabelDialog(self.state.label_hierarchy)
         self._new_label_dialog.modified_label.connect(self._handle_label_node_modified)
         self._new_label_dialog.add_new_label_requested.connect(self.handle_new_label_requested)
         self._new_label_dialog.hide()
@@ -711,9 +716,11 @@ class LabelEditor(QObject):
         self._label_tree_model.dataChanged.emit(index, index, [Qt.DisplayRole, Qt.DecorationRole])
 
     def modify_label_node(self, node: Node):
+        self._setup_new_label_dialog()
         self._new_label_dialog.modify_label(node.label)
 
     def _add_new_label(self):
+        self._setup_new_label_dialog()
         node: Node = self._label_context_action_add.data()
         self._new_label_dialog.add_new_label(node.label)
 
