@@ -5,7 +5,7 @@ from typing import Optional, Tuple
 
 import PySide6
 import cv2
-import numba
+# import numba
 import numpy as np
 import scipy
 from PySide6.QtCore import Qt, Signal, QRectF
@@ -128,7 +128,8 @@ class LabelLayer(Layer):
             self.outline_mask_buffer.fill(1)
         level_img = self.state.current_photo[self.state.current_label_name][self.state.current_label_level]
         used_labels = np.unique(level_img)
-        cmap = {label: QColor.fromRgb(*self.state.colormap[label]).rgba() for label in used_labels}
+        # cmap = {label: QColor.fromRgb(*self.state.colormap[label]).rgba() for label in used_labels}
+        cmap = {label: QColor.fromRgb(*self.state.colormap.get(label, (255, 255, 255))).rgba() for label in used_labels}
         if 0 in used_labels:
             cmap[0] = QColor(0, 0, 0, 0).rgba()
         for label in used_labels:
@@ -468,25 +469,25 @@ def compute_outline2(label_img: np.ndarray) -> np.ndarray:
     return 255 * (sums == 0).astype(np.uint8)
 
 
-@numba.jit
-def compute_outline(label_img: np.ndarray) -> np.ndarray:
-    # result = np.zeros(label_img.shape + (1,), dtype=label_img.dtype)
-    result = 255 * np.ones(label_img.shape, dtype=np.uint8)
-    d = [-1, 0, 1]
-    for y in range(label_img.shape[0]):
-        for x in range(label_img.shape[1]):
-            if label_img[y, x] == 0:
-                continue
-            lab = label_img[y, x]
-            for k in d:
-                for j in d:
-                    if k == 0 and j == 0 or outside(y + k, x + j, label_img.shape) or abs(k) + abs(j) > 1:
-                        continue
-                    if label_img[y + k, x + j] != lab:
-                        result[y, x] = 0  # label_img[y, x]
-    return result
+# @numba.jit
+# def compute_outline(label_img: np.ndarray) -> np.ndarray:
+#     # result = np.zeros(label_img.shape + (1,), dtype=label_img.dtype)
+#     result = 255 * np.ones(label_img.shape, dtype=np.uint8)
+#     d = [-1, 0, 1]
+#     for y in range(label_img.shape[0]):
+#         for x in range(label_img.shape[1]):
+#             if label_img[y, x] == 0:
+#                 continue
+#             lab = label_img[y, x]
+#             for k in d:
+#                 for j in d:
+#                     if k == 0 and j == 0 or outside(y + k, x + j, label_img.shape) or abs(k) + abs(j) > 1:
+#                         continue
+#                     if label_img[y + k, x + j] != lab:
+#                         result[y, x] = 0  # label_img[y, x]
+#     return result
 
 
-@numba.jit
-def outside(y, x, shape):
-    return y < 0 or y >= shape[0] or x < 0 or x >= shape[1]
+# @numba.jit
+# def outside(y, x, shape):
+#     return y < 0 or y >= shape[0] or x < 0 or x >= shape[1]
