@@ -10,9 +10,9 @@ from PySide6.QtCore import Qt, QItemSelection, QModelIndex, QItemSelectionModel,
 from PySide6.QtGui import QIcon, QPixmap, QColor, QBrush
 from PySide6.QtWidgets import QDialog, QTreeWidgetItem, QTreeWidget, QAbstractItemView, QDialogButtonBox, QVBoxLayout, \
     QWidget, QGroupBox, QFileDialog, QMessageBox
-from common.utils import let_user_save_path, attempt_to_save_with_retries, save_text, let_user_open_path, \
-    catch_exception_and_show_messagebox
 
+from maphis.common.utils import let_user_save_path, attempt_to_save_with_retries, save_text, let_user_open_path, \
+    catch_exception_and_show_messagebox
 from maphis.common.common import Info
 from maphis.common.label_hierarchy import Node, LabelHierarchy
 from maphis.common.label_tree_model import LabelTreeModel, LabelTreeMode
