@@ -61,8 +61,11 @@ class MeasurementsViewer(QWidget):
             action = self._export_menu.addAction(gen_action.info.name)
             action.setData(gen_action)
             # self._export_menu.addAction(action)
-        self._default_export_action: QAction = self._export_menu.actions()[0]
+        self._default_export_action: typing.Optional[QAction] = None
+        if len(self._export_menu.actions()) > 0:
+            self._default_export_action = self._export_menu.actions()[0]
         self.ui.btnExport.setText('Export measurements')
+        self.ui.btnExport.setEnabled(len(self._export_menu.actions()) > 0)
 
         self.ui.btnExport.setMenu(self._export_menu)
 
