@@ -11,6 +11,7 @@ from typing import Optional, List, Any, Union, Dict
 from PySide6.QtCore import QAbstractItemModel, QObject, QModelIndex, Qt, Signal, QSortFilterProxyModel, QItemSelection
 from PySide6.QtWidgets import QWidget, QVBoxLayout
 
+from maphis import MAPHIS_PATH
 from maphis.common.plugin import RegionComputation, Plugin, PropertyComputation, GeneralAction
 from maphis.common.state import State
 from maphis.common.tool import Tool
@@ -454,16 +455,16 @@ def load_computations(comp_folder: Path) -> Union[List[RegionComputation], List[
 def load_tools(plugin_key: str) -> List[Tool]:
     tools: List[Tool] = []
     try:
-        with resources.path(f'maphis.plugins.{plugin_key}', 'tools') as tools_folder:
-            if not tools_folder.exists():
-                return []
-            for file in os.scandir(tools_folder):
-                if file.is_dir() or file.name.startswith('_') or not file.name.endswith('.py'):
-                    continue
-                module_name = file.name.split('.')[0]
-                module = import_module(f'maphis.plugins.{plugin_key}.tools.{module_name}')
-                tool_cls = inspect.getmembers(module, is_tool)
-                tools.extend(tool_cls)
+        tools_folder = MAPHIS_PATH / 'plugins' / plugin_key / 'tools'
+        if not tools_folder.exists():
+            return []
+        for file in os.scandir(tools_folder):
+            if file.is_dir() or file.name.startswith('_') or not file.name.endswith('.py'):
+                continue
+            module_name = file.name.split('.')[0]
+            module = import_module(f'maphis.plugins.{plugin_key}.tools.{module_name}')
+            tool_cls = inspect.getmembers(module, is_tool)
+            tools.extend(tool_cls)
     except FileNotFoundError:
         return []
     return tools
