@@ -4,7 +4,8 @@ from pathlib import Path
 from typing import Optional
 
 from PySide6.QtWidgets import QApplication
-from common.utils import attempt_to_save_with_retries
+
+from maphis.common.utils import attempt_to_save_with_retries
 from maphis.common.common import Info
 from maphis.common.plugin import GeneralAction, ActionContext
 from maphis.common.state import State
