@@ -13,6 +13,7 @@ from PySide6.QtCore import QUrl
 from PySide6.QtWidgets import QMessageBox, QWidget, QPushButton, QVBoxLayout, QDialogButtonBox, \
     QDialog, QApplication, QScrollArea, QSizePolicy, QHBoxLayout, QFileDialog
 
+from maphis import MAPHIS_PATH
 from maphis.common.units import Value, convert_value
 from maphis.common.common import Info
 from maphis.common.photo import Photo
@@ -395,22 +396,25 @@ class ProfileFusion(GeneralAction):
 
     def _get_recent_open_save_location(self) -> typing.Optional[Path]:
         try:
-            with importlib.resources.path('maphis.plugins.profile_register.general', '.') as path:
-                if not (recent_path_file := path / 'recent_save_open_path.txt').exists():
-                    return Path.home()
-                with open(recent_path_file, 'r') as f:
-                    recent_path = Path(f.read())
-                return recent_path
-        except Exception:
+            path = MAPHIS_PATH / 'plugins' / 'profile_register' / 'general'
+            if not (recent_path_file := path / 'recent_save_open_path.txt').exists():
+                return Path.home()
+            with open(recent_path_file, 'r') as f:
+                recent_path = Path(f.read())
+            return recent_path
+        except Exception as e:
+            print(e)
             # TODO log it
             return None
 
     def _save_recent_open_save_location(self, loc: Path):
         try:
-            with importlib.resources.path('maphis.plugins.profile_register.general', '.') as path:
-                with open(path / 'recent_save_open_path.txt', 'w') as f:
-                    f.write(str(loc))
-        except Exception:
+            # with importlib.resources.path('maphis.plugins.profile_register.general', '.') as path:
+            path = MAPHIS_PATH / 'plugins' / 'profile_register' / 'general'
+            with open(path / 'recent_save_open_path.txt', 'w') as f:
+                f.write(str(loc))
+        except Exception as e:
+            print(e)
             # TODO log it
             return
 
